@@ -1,38 +1,38 @@
 from os.path import join as path_join
 from sqlite3 import Connection
 from sqlite3 import connect as sqlite3_connect
+from typing import Iterator
 from typing import List
 from typing import Union
 
 from .__version__ import __database_version__
 
 # Entries guide - USERS
-# v2.6      v3.0
-# USER      USERNAME
-# USERFULL  FOLDERS
-# FOLDERS   GALLERY
-# GALLERY   SCRAPS
-# SCRAPS    FAVORITES
-# FAVORITES EXTRAS
-# EXTRAS
+# v3.0
+# 0 USERNAME
+# 1 FOLDERS
+# 2 GALLERY
+# 3 SCRAPS
+# 4 FAVORITES
+# 5 EXTRAS
 
 # Entries guide - SUBMISSIONS
-# v2.6              v3.0
-# 0   ID            ID
-# 1   AUTHOR        AUTHOR
-# 2   AUTHORURL     TITLE
-# 3   TITLE         UDATE
-# 4   UDATE         DESCRIPTION
-# 5   DESCRIPTION   TAGS
-# 6   TAGS          CATEGORY
-# 7   CATEGORY      SPECIES
-# 8   SPECIES       GENDER
-# 9   GENDER        RATING
-# 10  RATING        FILELINK
-# 11  FILELINK      FILEEXT
-# 12  FILENAME      FILESAVED
-# 13  LOCATION
-# 14  SERVER
+# v3.0
+# 0  ID
+# 1  AUTHOR
+# 2  TITLE
+# 3  UDATE
+# 4  DESCRIPTION
+# 5  TAGS
+# 6  CATEGORY
+# 7  SPECIES
+# 8  GENDER
+# 9  RATING
+# 10 FILELINK
+# 11 FILEEXT
+# 12 FILESAVED
+# 13 LOCATION
+# 14 SERVER
 
 
 keys_submissions: List[str] = [
@@ -76,15 +76,16 @@ def insert(db: Connection, table: str, keys: List[str], values: List[Union[int,
     )
 
 
-def select(db: Connection, table: str, select_fields: List[str], key: str, key_value: Union[int, str]) -> List[tuple]:
+def select(db: Connection, table: str, select_fields: List[str], key: str, key_value: Union[int, str]
+           ) -> Iterator[tuple]:
     return db.execute(
         f'''SELECT {",".join(select_fields)} FROM {table} WHERE {key} = ?''',
         (key_value,)
-    ).fetchall()
+    )
 
 
-def select_all(db: Connection, table: str, select_fields: List[str]) -> List[tuple]:
-    return db.execute(f'''SELECT {",".join(select_fields)} FROM {table}''').fetchall()
+def select_all(db: Connection, table: str, select_fields: List[str]) -> Iterator[tuple]:
+    return db.execute(f'''SELECT {",".join(select_fields)} FROM {table}''')
 
 
 def update(db: Connection, table: str, fields: List[str], values: List[Union[int, str]], key: str, key_value: str):
@@ -104,7 +105,7 @@ def delete(db: Connection, table: str, key: str, key_value: Union[int, str]):
     db.execute(f"""DELETE FROM {table} where {key} = ?""", (key_value,))
 
 
-def count(db:  Connection, table: str) -> int:
+def count(db: Connection, table: str) -> int:
     return db.execute(f"SELECT COUNT(*) FROM {table}").fetchall()[0][0]
 
 
